@@ -16,19 +16,10 @@ class charitable_deduction(Variable):
             tax_unit, period, ["charitable_non_cash_donations"]
         )
         positive_agi = tax_unit("positive_agi", period)
-        ceiling = parameters(
-            period
-        ).gov.irs.deductions.itemized.charity.ceiling
+        p = parameters(period).gov.irs.deductions.itemized.charity.ceiling
         capped_non_cash_donations = min_(
-            non_cash_donations, ceiling.non_cash * positive_agi
-        )
-        charitable_deduction_for_non_itemizers = tax_unit(
-            "charitable_deduction_for_non_itemizers", period
-        )
-        reduced_cash_donations = max_(
-            cash_donations - charitable_deduction_for_non_itemizers, 0
-        )
-        return min_(
-            capped_non_cash_donations + reduced_cash_donations,
-            ceiling.all * positive_agi,
+            non_cash_donations, p.non_cash * positive_agi
         )
+
+        total_cap = p.all * positive_agi
+        return min_(capped_non_cash_donations + cash_donations, total_cap)
