@@ -15,7 +15,12 @@ class ca_state_supplement_medical_care_facility_amount(Variable):
             period
         ).gov.states.ca.cdss.state_supplement.payment_standard
         # Medical care facility amount
-        medical_care_facility_count = add(
-            spm_unit, period, ["ca_in_medical_care_facility"]
+        person = spm_unit.members
+        eligible = person("ca_state_supplement_eligible_person", period)
+        in_medical_care_facility = person(
+            "ca_in_medical_care_facility", period
+        )
+        medical_care_facility_count = spm_unit.sum(
+            in_medical_care_facility * eligible
         )
         return medical_care_facility_count * p.allowance.medical_care_facility
