@@ -20,7 +20,7 @@ class snap(Variable):
         if parameters(period).gov.usda.snap.abolish_snap:
             return 0
         elif parameters(period).gov.simulation.reported_snap:
-            return spm_unit("snap_reported", period) / MONTHS_IN_YEAR
+            return spm_unit("snap_reported", period)
         else:
             value = add(
                 spm_unit,
